Description Usage Arguments Value
Assumes that the Concourse API key is in the .Renviron file. Default name of variable is "CONCOURSE_KEY". If absent, looks in the working directory for txt file with token named token.txt.
1 | loadToken(env_var_name)
|
env_var_name |
Character of the name of the env variable |
token A character vector of token
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.