loadURL: Load Server URL

Description Usage Arguments Value

View source: R/loadURL.R

Description

Will load server url from system variable or defer to supplied url. Assumes that the following url variables have been set in the .Renviron folder: CONCOURSE_URL, CONCOURSE_SANDBOX

Usage

1
loadURL(server)

Arguments

server

Either the name of the environment variable for the url, or a provided string beginning with 'http'

Value

url A character vector of of the url


erikpal/concourse_client documentation built on Oct. 2, 2021, 8:07 a.m.