Description Usage Arguments Value
Will load server url from system variable or defer to supplied url. Assumes that the following url variables have been set in the .Renviron folder: CONCOURSE_URL, CONCOURSE_SANDBOX
1 | loadURL(server)
|
server |
Either the name of the environment variable for the url, or a provided string beginning with 'http' |
url A character vector of of the url
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.